==> ckeditor_4.16.0+dfsg.orig.tar.xz: ckeditor4-4.16.0/plugins/link/lang/de-ch.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'de-ch', {
	acccessKey: 'Zugriffstaste',
	advanced: 'Erweitert',
	advisoryContentType: 'Inhaltstyp',
	advisoryTitle: 'Titel Beschreibung',
	anchor: {
		toolbar: 'Anker',
		menu: 'Anker bearbeiten',
		title: 'Ankereigenschaften',
		name: 'Ankername',
		errorName: 'Bitte geben Sie den Namen des Ankers ein',
		remove: 'Anker entfernen'
	},
	anchorId: 'Nach Elementkennung',
	anchorName: 'Nach Ankername',
	charset: 'Verknüpfter Ressourcenzeichensatz',
	cssClasses: 'Formatvorlagenklasse',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail-Adresse',
	emailBody: 'Nachrichtentext',
	emailSubject: 'Betreffzeile',
	id: 'Kennung',
	info: 'Linkinfo',
	langCode: 'Sprachcode',
	langDir: 'Schreibrichtung',
	langDirLTR: 'Links nach Rechts (LTR)',
	langDirRTL: 'Rechts nach Links (RTL)',
	menu: 'Link bearbeiten',
	name: 'Name',
	noAnchors: '(Keine Anker im Dokument vorhanden)',
	noEmail: 'Bitte geben Sie E-Mail-Adresse an',
	noUrl: 'Bitte geben Sie die Link-URL an',
	noTel: 'Please type the phone number', // MISSING
	other: '<andere>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Abhängig (Netscape)',
	popupFeatures: 'Pop-up Fenstereigenschaften',
	popupFullScreen: 'Vollbild (IE)',
	popupLeft: 'Linke Position',
	popupLocationBar: 'Adressleiste',
	popupMenuBar: 'Menüleiste',
	popupResizable: 'Grösse änderbar',
	popupScrollBars: 'Rollbalken',
	popupStatusBar: 'Statusleiste',
	popupToolbar: 'Werkzeugleiste',
	popupTop: 'Obere Position',
	rel: 'Beziehung',
	selectAnchor: 'Anker auswählen',
	styles: 'Style',
	tabIndex: 'Tab-Index',
	target: 'Zielseite',
	targetFrame: '<Frame>',
	targetFrameName: 'Ziel-Fenster-Name',
	targetPopup: '<Pop-up Fenster>',
	targetPopupName: 'Pop-up Fenster-Name',
	title: 'Link',
	toAnchor: 'Anker in dieser Seite',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Link einfügen/editieren',
	type: 'Link-Typ',
	unlink: 'Link entfernen',
	upload: 'Hochladen'
} );

==> ckeditor_4.22.1+dfsg1.orig.tar.xz: ckeditor4-4.22.1/plugins/link/lang/de-ch.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'de-ch', {
	acccessKey: 'Zugriffstaste',
	advanced: 'Erweitert',
	advisoryContentType: 'Inhaltstyp',
	advisoryTitle: 'Titel Beschreibung',
	anchor: {
		toolbar: 'Anker',
		menu: 'Anker bearbeiten',
		title: 'Ankereigenschaften',
		name: 'Ankername',
		errorName: 'Bitte geben Sie den Namen des Ankers ein',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Anker entfernen'
	},
	anchorId: 'Nach Elementkennung',
	anchorName: 'Nach Ankername',
	charset: 'Verknüpfter Ressourcenzeichensatz',
	cssClasses: 'Formatvorlagenklasse',
	download: 'Herunterladen erzwingen',
	displayText: 'Anzeigetext',
	emailAddress: 'E-Mail-Adresse',
	emailBody: 'Nachrichtentext',
	emailSubject: 'Betreffzeile',
	id: 'Kennung',
	info: 'Linkinfo',
	langCode: 'Sprachcode',
	langDir: 'Schreibrichtung',
	langDirLTR: 'Links nach Rechts (LTR)',
	langDirRTL: 'Rechts nach Links (RTL)',
	menu: 'Link bearbeiten',
	name: 'Name',
	noAnchors: '(Keine Anker im Dokument vorhanden)',
	noEmail: 'Bitte geben Sie E-Mail-Adresse an',
	noUrl: 'Bitte geben Sie die Link-URL an',
	noTel: 'Bitte geben Sie die Telefonnummer ein',
	other: '<andere>',
	phoneNumber: 'Telefonnummer',
	popupDependent: 'Abhängig (Netscape)',
	popupFeatures: 'Pop-up Fenstereigenschaften',
	popupFullScreen: 'Vollbild (IE)',
	popupLeft: 'Linke Position',
	popupLocationBar: 'Adressleiste',
	popupMenuBar: 'Menüleiste',
	popupResizable: 'Grösse änderbar',
	popupScrollBars: 'Rollbalken',
	popupStatusBar: 'Statusleiste',
	popupToolbar: 'Werkzeugleiste',
	popupTop: 'Obere Position',
	rel: 'Beziehung',
	selectAnchor: 'Anker auswählen',
	styles: 'Style',
	tabIndex: 'Tab-Index',
	target: 'Zielseite',
	targetFrame: '<Frame>',
	targetFrameName: 'Ziel-Fenster-Name',
	targetPopup: '<Pop-up Fenster>',
	targetPopupName: 'Pop-up Fenster-Name',
	title: 'Link',
	toAnchor: 'Anker in dieser Seite',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Link einfügen/editieren',
	type: 'Link-Typ',
	unlink: 'Link entfernen',
	upload: 'Hochladen'
} );
